pub struct ConIterOfVec<T: Send + Sync + Default> { /* private fields */ }
A concurrent iterator over a vector, consuming the vector and yielding its elements.

Implementations

source

impl<T: Send + Sync + Default> ConIterOfVec<T>

source

pub fn new(vec: Vec<T>) -> Self

Consumes and creates a concurrent iterator of the given vec.